# *Anti*body*D*esign

[![PyPI version](https://badge.fury.io/py/antid.svg)](https://badge.fury.io/py/antid)

A Python package containing helper functions for antibody design.

## Installation

Install `antid` from PyPI. It is recommended to use a virtual environment.

With `uv`:

```bash
uv pip install antid
```

With `pip`:

```bash
pip install antid
```

## Usage

> TODO

## Development

To set up a development environment, clone the repository and use `uv` to create a virtual environment and install the dependencies.

```bash
# Clone the repository
git clone https://github.com/y1zhou/antid.git
cd antid

# Create and activate a virtual environment
uv venv antid
source .venv/bin/activate

# Install the package in editable mode with development dependencies
uv pip install -e .[dev]
```

## License

This project is licensed under the Apache License 2.0.
